==> edc_adverse_event-0.1.20-py3-none-any.whl: edc_adverse_event/urls.py <==
from django.apps import apps as django_apps
from django.urls.conf import path
from django.views.generic.base import RedirectView
from edc_adverse_event.admin_site import edc_adverse_event_admin

from .views import (
    AeHomeView,
    TmgHomeView,
    NewTmgAeListboardView,
    OpenTmgAeListboardView,
    ClosedTmgAeListboardView,
    DeathListboardView as TmgDeathListboardView,
    SummaryListboardView as TmgSummaryListboardView,
)

app_name = "edc_adverse_event"

subject_identifier_pattern = django_apps.get_app_config(
    "edc_identifier"
).subject_identifier_pattern  # "092\-[0-9\-]+"


urlpatterns = NewTmgAeListboardView.urls(
    namespace=app_name,
    label="new_tmg_ae_listboard",
    identifier_pattern=subject_identifier_pattern,
)
urlpatterns += OpenTmgAeListboardView.urls(
    namespace=app_name,
    label="open_tmg_ae_listboard",
    identifier_pattern=subject_identifier_pattern,
)
urlpatterns += ClosedTmgAeListboardView.urls(
    namespace=app_name,
    label="closed_tmg_ae_listboard",
    identifier_pattern=subject_identifier_pattern,
)
urlpatterns += TmgDeathListboardView.urls(
    namespace=app_name,
    label="tmg_death_listboard",
    identifier_pattern=subject_identifier_pattern,
)
urlpatterns += TmgSummaryListboardView.urls(
    namespace=app_name,
    label="tmg_summary_listboard",
    identifier_pattern=subject_identifier_pattern,
)
urlpatterns += [
    path("tmg/", TmgHomeView.as_view(), name="tmg_home_url"),
    path("ae/", AeHomeView.as_view(), name="ae_home_url"),
    path("admin/", edc_adverse_event_admin.urls),
    path("", RedirectView.as_view(url="/edc_adverse_event/admin/"), name="home_url"),
]

==> edc_adverse_event-0.1.38-py3-none-any.whl: edc_adverse_event/urls.py <==
from django.urls.conf import path
from django.views.generic.base import RedirectView
from edc_adverse_event.admin_site import edc_adverse_event_admin
from edc_protocol.protocol import Protocol

from .views import (
    AeHomeView,
    TmgHomeView,
    NewTmgAeListboardView,
    OpenTmgAeListboardView,
    ClosedTmgAeListboardView,
    DeathListboardView as TmgDeathListboardView,
    SummaryListboardView as TmgSummaryListboardView,
)

app_name = "edc_adverse_event"


urlpatterns = NewTmgAeListboardView.urls(
    namespace=app_name,
    label="new_tmg_ae_listboard",
    identifier_pattern=Protocol().subject_identifier_pattern,
)
urlpatterns += OpenTmgAeListboardView.urls(
    namespace=app_name,
    label="open_tmg_ae_listboard",
    identifier_pattern=Protocol().subject_identifier_pattern,
)
urlpatterns += ClosedTmgAeListboardView.urls(
    namespace=app_name,
    label="closed_tmg_ae_listboard",
    identifier_pattern=Protocol().subject_identifier_pattern,
)
urlpatterns += TmgDeathListboardView.urls(
    namespace=app_name,
    label="tmg_death_listboard",
    identifier_pattern=Protocol().subject_identifier_pattern,
)
urlpatterns += TmgSummaryListboardView.urls(
    namespace=app_name,
    label="tmg_summary_listboard",
    identifier_pattern=Protocol().subject_identifier_pattern,
)
urlpatterns += [
    path("tmg/", TmgHomeView.as_view(), name="tmg_home_url"),
    path("ae/", AeHomeView.as_view(), name="ae_home_url"),
    path("admin/", edc_adverse_event_admin.urls),
    path("", RedirectView.as_view(url="/edc_adverse_event/admin/"), name="home_url"),
]
